import axios from 'axios'
import { useUserStore } from '@/store'
console.log('process.env:')
const instance = axios.create({
  baseURL: process.env.NODE_ENV === 'development' ? 'https://open.test.luojigou.vip' : '/zd-api',
  // baseURL: process.env.NODE_ENV !== 'development' ? 'https://open.test.luojigou.vip' : 'https://open.api.luojigou.vip',
  timeout: 30000,
  headers: {
    'Content-Security-Policy': 'default-src \'*\''
  }
})

/**
 * 该函数捕获一个错误并返回一个被拒绝的承诺。
 * @param {any} error - `error` 参数是 `any` 类型，这意味着它可以是任何数据类型。它用作 `catchErr` 函数的输入参数。
 * @returns `catchErr` 函数返回一个被拒绝的 Promise，并传递了 `error` 参数作为拒绝的原因。
 */
const catchErr = (response) => {
  const { data } = response
  console.log('data', data)
  if (data.status === 500) {
    // eslint-disable-next-line no-undef
    showToast(data.msg)
    // message.error(data.msg)
  } else if (data.status === 401) {
    useUserStore().logout()
  }
}

instance.interceptors.request.use(config => {
  config.headers.token = useUserStore().userInfo.token
  return config
}, function (error) {
  return Promise.reject(error)
})

instance.interceptors.response.use(function (response) {
  catchErr(response)
  return response.data
}, error => {
  catchErr(error.response)
  return Promise.reject(error)
})

export default instance.request
