import { defineStore } from 'pinia'
import { ref } from 'vue'
import { login, resetPassword, smsGetCode } from '@/api/user'
import router from '@/router'

export const useUserStore = defineStore('useUserStore', () => {
  const userInfo = ref({
    id: '',
    name: '',
    phone: '',
    token: ''
  })

  const code = ref('')
  const _login = async (_data) => {
    const { data, status } = await login(_data)
    if (status === 200) {
      // eslint-disable-next-line no-undef
      showToast('登录成功')
      userInfo.value = data
      router.push({
        path: '/record'
      })
    }
  }

  const logout = () => {
    userInfo.value = {
      id: '',
      name: '',
      phone: '',
      token: ''
    }
    router.push({
      path: '/login'
    })
  }

  const _resetPassword = async (data) => {
    const { status } = await resetPassword(data)
    if (status === 200) {
      // eslint-disable-next-line no-undef
      showToast('重置成功')
      router.replace({
        path: '/login'
      })
    }
  }
  const _smsGetCode = async (phone) => {
    const data = await smsGetCode(phone)
    if (data.status === 200) {
      // eslint-disable-next-line no-undef
      showToast('验证码已发送')
    }
    return data
  }

  return {
    userInfo,
    code,
    login: _login,
    logout,
    resetPassword: _resetPassword,
    smsGetCode: _smsGetCode
  }
}, {
  persist: true
})
